summaryrefslogtreecommitdiffstats
path: root/kjsembed/jssecuritypolicy.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 15:55:57 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 15:55:57 -0600
commit9ba04742771370f59740e32e11c5f3a1e6a1b70a (patch)
treec81c34dae2b3b1ea73801bf18a960265dc4207f7 /kjsembed/jssecuritypolicy.h
parent1a96c45b22d01378202d9dc7ed9c47acd30f966e (diff)
downloadtdebindings-9ba04742771370f59740e32e11c5f3a1e6a1b70a.tar.gz
tdebindings-9ba04742771370f59740e32e11c5f3a1e6a1b70a.zip
Initial TQt conversion
Diffstat (limited to 'kjsembed/jssecuritypolicy.h')
-rw-r--r--kjsembed/jssecuritypolicy.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kjsembed/jssecuritypolicy.h b/kjsembed/jssecuritypolicy.h
index 26e55881..df39117e 100644
--- a/kjsembed/jssecuritypolicy.h
+++ b/kjsembed/jssecuritypolicy.h
@@ -36,7 +36,7 @@ class JSObjectProxy;
* A SecurityPolicy must define tests for the following situations:
* <ul>
* <li>Does this request come from the correct @ref KJS::Interpreter ?
* <li>Is the script allowed to access the specified TQObject ?
* <li>Is the script allowed to access the specified property ?
* </ul>
* The various isAllowed() methods are called automatically by @ref JSObjectProxy
@@ -47,7 +47,7 @@ class JSObjectProxy;
* <ul>
* <li>Only the interpreter specified when the initial binding was
* defined may access the proxy.
- * <li>Scripts may only access QObjects that are children of the root
+ * <li>Scripts may only access TQObjects that are children of the root
* object. The root object is specified when the embedding application
* creates the initial binding, and is automatically inherited by any
* sub-proxies that may be created by the script.
@@ -107,20 +107,20 @@ public:
virtual bool isInterpreterAllowed( const JSObjectProxy *prx, const KJS::Interpreter *interp ) const;
/**
* Returns true if scripts are allowed to see the specified TQObject.
*/
- virtual bool isObjectAllowed( const JSObjectProxy *prx, const TQObject *obj ) const;
+ virtual bool isObjectAllowed( const JSObjectProxy *prx, const TTQObject *obj ) const;
/**
* Returns true if scripts are allowed to see the specified property.
*/
- virtual bool isPropertyAllowed( const JSObjectProxy *prx, const TQObject *obj, const char *prop ) const;
+ virtual bool isPropertyAllowed( const JSObjectProxy *prx, const TTQObject *obj, const char *prop ) const;
/**
* Returns true if scripts are allowed to create the specified child object.
*/
- virtual bool isCreateAllowed( const JSObjectProxy *prx, const TQObject *parent,
- const TQString &clazz, const TQString &name ) const;
+ virtual bool isCreateAllowed( const JSObjectProxy *prx, const TTQObject *parent,
+ const TTQString &clazz, const TTQString &name ) const;
/**
* Returns the default SecurityPolicy.
@@ -36,7 +36,7 @@ class JSObjectProxy;
* <ul>
* <li>Does this request come from the correct @ref KJS::Interpreter ?
- * <li>Is the script allowed to access the specified TQObject ?
+ * <li>Is the script allowed to access the specified TTQObject ?
* <li>Is the script allowed to access the specified property ?
* </ul>
@@ -107,20 +107,20 @@ public:
virtual bool isInterpreterAllowed( const JSObjectProxy *prx, const KJS::Interpreter *interp ) const;
/**
- * Returns true if scripts are allowed to see the specified TQObject.
+ * Returns true if scripts are allowed to see the specified TTQObject.
*/